import rsa
import re
import base64
from datetime import datetime

# Open key file.
with open('footscan9_license_private_key.pem', mode='rb') as privkey:
    keydata = privkey.read()

privkey = rsa.PrivateKey.load_pkcs1(keydata)

# Open file to sign.
with open('test.rsconfig', mode='r', encoding='utf-8') as infile:
    message = infile.read()

print('Input file:\n----------')
print(message)
print('----------')

# Replace the header.
message = message.replace('<rsconfig>', '<rsconfig signature="[SIGNATURE]" createTime="{}" systemId="0000000001" revision="0001">'.format(datetime.utcnow().isoformat()))

print('\nFile to sign:\n----------')
print(message)
print('----------')

# Normalize the file.
signmessage = ''.join(message.split())
signmessage = re.sub('\<\!--.*?--\!\>', '', signmessage)


print('\nNormalized message:\n----------')
print(signmessage)
print('----------')

# Sign the normalized file.
signature = rsa.sign(signmessage.encode('utf-8'), privkey, 'SHA-512')
signature = base64.urlsafe_b64encode(signature).decode('utf-8')

print('\nSignature:\n----------')
print(signature)
print('----------')

# Replace the signature in the file.
message = message.replace('[SIGNATURE]', signature)

print('\nSigned message:\n----------')
print(message)
print('----------')

with open('signed.rsconfig', 'w') as outfile:
    outfile.write(message)
